;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x8d744ddc02489a23f29d4dc9142c95a0 . "./code.cg2js/cg-acache.fasl")
(#xe1eb3fdc98a38296294e65d1c60396bf . "./code.cg2js/cg-base.fasl")
(#xda4cd058b0ae1e999ccd6da0b4679e94 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xabe0d8a11e8fa1b8c6e15f3906e2448c . "./code.cg2js/cg-bitmap-pane.fasl")
(#x3b8146a56f3bc900e8dcd46b1bfc55c2 . "./code.cg2js/cg-bitmap-stream.fasl")
(#xdf8bfeffb0600a524ddb65e32c7cf1f5 . "./code.cg2js/cg-button.fasl")
(#xf3ae72e7d85accf098e1510e4a446e90 . "./code.cg2js/cg-calendar.fasl")
(#xc9f457ab3a808dfd01fb9b233a02bbf2 . "./code.cg2js/cg-caret.fasl")
(#x557749018fd3c694f3527feccb7b6f9b . "./code.cg2js/cg-chart-or-plot.fasl")
(#x03a77ddab3f66b2c237c6ebbc298f0b3 . "./code.cg2js/cg-chart-widget.fasl")
(#x3a269aef919885e80243b528b293589a . "./code.cg2js/cg-check-box.fasl")
(#x23089dd2b445f0379cc89c5ac32cccaf . "./code.cg2js/cg-choice-list.fasl")
(#xe4ac87f7fd53b58449c28373c3ddf9f7 . "./code.cg2js/cg-choose-printer.fasl")
(#xa40a3c154ab725305dd2e02f38ee867a . "./code.cg2js/cg-class-grid.fasl")
(#xc7f8c2c361e6c717ab03cabea6a38ebf . "./code.cg2js/cg-class-slot-grid.fasl")
(#xfed74afdfc28afc54237b0ac5c654073 . "./code.cg2js/cg-class-support.fasl")
(#x30adfb37143ebf57871c9a6921580c0f . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xe3ab2631f601e030ad4c086332d394b5 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x73a4177aa870987c0febb6a75682c319 . "./code.cg2js/cg-clipboard.fasl")
(#x1c832d217306a2f94891ce4620ca3ea2 . "./code.cg2js/cg-color-dialog.fasl")
(#xde421b09aafe5d92252627c50babfddc . "./code.cg2js/cg-combo-box.fasl")
(#x61b8c5554f52cf8d36797a365890ec4b . "./code.cg2js/cg-common-control.fasl")
(#xd5cb84f2a4c6e3ac17434da25d30d9e8 . "./code.cg2js/cg-comtab.fasl")
(#x0c22083da5ee0b6e11404a8863a53c3f . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x6f4aa5849b96690cf54250ef85104ee0 . "./code.cg2js/cg-curve.fasl")
(#x1abb56ed3c4415d4e393e0c805093dfb . "./code.cg2js/cg-dde-utils.fasl")
(#xd9d2b30bb311d3421f5697e8e14b1c36 . "./code.cg2js/cg-dev.fasl")
(#x6cd0ca2fad39824847475e9c34291268 . "./code.cg2js/cg-dialog-item.fasl")
(#x64cdacf250baccc885a93ea00ae1bae0 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#xe8b59ce64dfe50c1c68767be46916027 . "./code.cg2js/cg-directory-dialog.fasl")
(#xe8a150da9ad6e2b4e08e29f7c46ffaf3 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xeaeca0173c308ffac6768c5a30086bb2 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x3ddf4a8f8c0b8492d27b2c5ed2313400 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x4ef7d82dd47330f421592e9a54bdc0b2 . "./code.cg2js/cg-drawable.fasl")
(#x06f23111e2622542bf287c1878ac6749 . "./code.cg2js/cg-dropping-outline.fasl")
(#xf179595dfe02063a75ec2660e817e51c . "./code.cg2js/cg-edit-in-place.fasl")
(#xfa6f1cbdd2d042ce3d83a1e2a16467bd . "./code.cg2js/cg-editable-text.fasl")
(#x9254d73ee97c3eea77c4d334a9e4e660 . "./code.cg2js/cg-file-dialog.fasl")
(#xe756c56b50eee029ecbc21317dd73ffc . "./code.cg2js/cg-fill-texture.fasl")
(#x8b7db38bd0a7ab8f159828203ffe5491 . "./code.cg2js/cg-find-string-dialog.fasl")
(#xa9acd468b29eac35c48f406b2ef6fcdc . "./code.cg2js/cg-font-dialog.fasl")
(#x37dd22ef902cf9002408cc249c71cb0a . "./code.cg2js/cg-gesture-emulation.fasl")
(#xbbe6c32591c2522519bdab676f3dd476 . "./code.cg2js/cg-get-pixmap.fasl")
(#x9d81b79caa6a7905ef91ab1727e13b60 . "./code.cg2js/cg-get-position.fasl")
(#xfee56a989ac3e7a348756e9b9a6387cf . "./code.cg2js/cg-graphics-context.fasl")
(#x6601e4e2e9824a04ac060a6f17c871b5 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xbf87af0f8ff59cae8436060c7cb6bf25 . "./code.cg2js/cg-grid-widget.fasl")
(#x9cc3aa26b1b1ba2d01944cbb842eda24 . "./code.cg2js/cg-group-box.fasl")
(#xd18e434c250f62a0b252d5b443cb140a . "./code.cg2js/cg-header-control.fasl")
(#xcca790b8d6df07778f7e6d956aae0642 . "./code.cg2js/cg-hotspot.fasl")
(#xb8ab1ed3f65a8e7f1fdb6e5fd68e1264 . "./code.cg2js/cg-html-dialog.fasl")
(#x5a6af41e5ad4a8678fdd4d8e61c339d8 . "./code.cg2js/cg-html-widget.fasl")
(#x64d55c6482147b23c1318a8277c415c6 . "./code.cg2js/cg-icon-pixmap.fasl")
(#xec2892e0f1acfd1e7a5cdaf11b3fddc9 . "./code.cg2js/cg-icon.fasl")
(#x05dad8f9299c452abc219dcad36aa6ed . "./code.cg2js/cg-ie.fasl")
(#x45c318c12f9fb73d4343fd15c47beb1c . "./code.cg2js/cg-intersect-posbox.fasl")
(#x67b27d40f645a98d934a3c00cb40885f . "./code.cg2js/cg-intersect.fasl")
(#x21119bc81e445c1391034f2d80f41e08 . "./code.cg2js/cg-item-list.fasl")
(#xa738b944e9b8358c25cc7a5162ee613a . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x4f90449915985dd9e0897eae5d13a0ec . "./code.cg2js/cg-lamp.fasl")
(#xae2141a8b0c022be17592a25f33ebd70 . "./code.cg2js/cg-layout.fasl")
(#xc8128bc7d6280f3fd243cf4959396d5a . "./code.cg2js/cg-lettered-menu.fasl")
(#xc6e1b4c614a26e5590efe9d70d6ee354 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#xf8babcefffa49ad426dbecfb7be552b5 . "./code.cg2js/cg-lisp-text.fasl")
(#x7b7406c6e5861f7f6c5f5fe86d3a94da . "./code.cg2js/cg-lisp-widget.fasl")
(#xd7b29f5770157f681e4830d3a68071a6 . "./code.cg2js/cg-list-view.fasl")
(#xdb6fb1a0a68f9dfefd533fe4257e1d8c . "./code.cg2js/cg-mci.fasl")
(#xe027456790fa22563ce50513ecd4e61a . "./code.cg2js/cg-menu-tooltip.fasl")
(#x4a851cdb47d6382f45071089f812bc47 . "./code.cg2js/cg-menu.fasl")
(#x746a67713182b0847e446141af1350d5 . "./code.cg2js/cg-message-dialog.fasl")
(#x7b6a2f43d5ec7a9d29a7801b7a7fa93d . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#xaa2f88905676dfeff3bc3b28e5aef2c8 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x9e6860d12aaa05995867832e56d4675a . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xcd0c3a3441b5f4d209e0248d71da9d3d . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x638575fb708ad1db6dad6cd2e2988a1f . "./code.cg2js/cg-multi-picture-button.fasl")
(#xa9c2e1440b83919130ba1376a0883f45 . "./code.cg2js/cg-nodes.fasl")
(#x1ef2fd8249e333ff1382e3b3934c4d0a . "./code.cg2js/cg-object-editor-layout.fasl")
(#x63abfc8642ce026b6f6544a555bb1ef6 . "./code.cg2js/cg-object-editor.fasl")
(#xdff7dd947ee33f410a308119406b4dd1 . "./code.cg2js/cg-ocx.fasl")
(#x2130090ec54a190a6fe23d93ccd3e63d . "./code.cg2js/cg-os-widget.fasl")
(#xaed1fadcf2fbd5d54ee9cfcd31dc3a3c . "./code.cg2js/cg-os-window.fasl")
(#xb56b6fae56c43041ddcc34a055b282fb . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#xcf582aebb43132a2d1852f9c76d2bf82 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x21f190f1ecfb9306260b312f6e2740df . "./code.cg2js/cg-outline.fasl")
(#x0b9c6c95e37ac4c8e6cc4e75fc965812 . "./code.cg2js/cg-palette.fasl")
(#x3a4f49276a14e6b0b288eb03367c162d . "./code.cg2js/cg-paren-matching.fasl")
(#xe0dcbae658437efd6f7101a280068110 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x82d8126310598e5c6893b43562034d25 . "./code.cg2js/cg-picture-widget.fasl")
(#x0ed484533c465397d1db09b0bb0034ad . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x262d169380b23db5a3a0fb85d0b01646 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x7117bd32a4cb6e286481eaa68093194e . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x98e4f546a68a9b16e0599d257d89e1d1 . "./code.cg2js/cg-pixmap-widget.fasl")
(#xc4ff34a3a973353078c419e7d3356331 . "./code.cg2js/cg-pixmap.fasl")
(#xa1f880e6f2ffeb021e161f945924bd9d . "./code.cg2js/cg-player.fasl")
(#x3914210b37e7166317fee650dd0723ab . "./code.cg2js/cg-plot-widget.fasl")
(#x1750530d98729cd69022f16e11a4704b . "./code.cg2js/cg-printing.fasl")
(#x40e80cce7c3b75fae811f95ed9dbb947 . "./code.cg2js/cg-progress-indicator.fasl")
(#x56f32b8bc052691c1e0b1d600f8ee725 . "./code.cg2js/cg-project-window.fasl")
(#x2b99c2c2f86d1245674b7268c16dd7f1 . "./code.cg2js/cg-property.fasl")
(#x0e80c4ad44017a5bec747d68527a1538 . "./code.cg2js/cg-radio-button.fasl")
(#x2a991633afc805151de1d166e6bbac82 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x987f90690bc7fa57b466bc5003027b2a . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x8655f3625128c7468bc090211e921496 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#xe13389c8c1f045679a4ac1d480c67dae . "./code.cg2js/cg-rich-edit.fasl")
(#x5e35a72fe15c93f992f4208b64519f09 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x982864025b72afd1d210daafd3810f0b . "./code.cg2js/cg-scaling-stream.fasl")
(#x095a68583ff29da8dee3ec53e5480771 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x6eefd8dbbd98f064dcd7c093b3e806c0 . "./code.cg2js/cg-scroll-bar.fasl")
(#x58c7e49b9579deb94d2ed07ce7b422c2 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#xff6d5fd66b6b649bd11f11faf9d3489e . "./code.cg2js/cg-selected-object.fasl")
(#xe258f694c7720814c113adb4992bf1e2 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x398a0369f525f2a903be7f632fbc2823 . "./code.cg2js/cg-split-bar.fasl")
(#x8c9245d5ecb0b3024eb42d0b43e643de . "./code.cg2js/cg-static-text.fasl")
(#x775a0fd595ccaf626d40817a586ab08b . "./code.cg2js/cg-status-bar.fasl")
(#x5b38d0864e9de4f5daee016c6d95ad5f . "./code.cg2js/cg-string-dialog.fasl")
(#x13ab9f3d54cd270a297f46e9ee68ccd2 . "./code.cg2js/cg-tab-control.fasl")
(#x8b2f40c9e1027dc5592a73dcf037d095 . "./code.cg2js/cg-template-string.fasl")
(#xecf6ab197fe3109b23473c168447dea2 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xf5699313f93843544413a9b4d0fc7f77 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x4abdceb5278e2b3689a30932b2fc8b1b . "./code.cg2js/cg-text-edit-pane.fasl")
(#x05449b92378ddf058224b44796f5558e . "./code.cg2js/cg-text-or-combo.fasl")
(#xdbb66efdf8e018fc9206bb6b7ab9de83 . "./code.cg2js/cg-text-widget.fasl")
(#x6427b1e386c18230437bb518117ada48 . "./code.cg2js/cg-timer.fasl")
(#x17b3a177bb01904738223d5ed6315f98 . "./code.cg2js/cg-toggling-widget.fasl")
(#xd6a536b7b0f546a58402eae6872c04af . "./code.cg2js/cg-toolbar.fasl")
(#xee0821204979933519f9fb20316f500c . "./code.cg2js/cg-tooltip.fasl")
(#x856a7623fada7302bbd77e8e35c9e4e8 . "./code.cg2js/cg-touch.fasl")
(#xad1e42600d72e74038b81c7b6a83c4b8 . "./code.cg2js/cg-trackbar.fasl")
(#x18d5e914b1357bf620537cc596dcb955 . "./code.cg2js/cg-tray.fasl")
(#xb153c4ff62a4478262bc925c705570f4 . "./code.cg2js/cg-up-down-control.fasl")
(#xd7bcf44795b5b17b0925795f186adfe1 . "./code.cg2js/cg-utility-dialog.fasl")
(#x8c628ddf4b47845d3fb6bba02772b72d . "./code.cg2js/cg-web-browser-dde.fasl")
(#x70cc286753b60fa2454ef452a89c2bff . "./code.cg2js/cg-web-browser.fasl")
(#x3acd764d668199a3cf37b20328f62e7e . "./code.cg2js/cg-wrap-string.fasl")
(#x9ad71c87c9adbab939ffffc9b63dfcb4 . "./code.cg2js/cg-yes-no-list.fasl")
(#xaf0c41c1ad2fd33a71359820da9b773b . "./code.cg2js/cg.fasl")
(#xd63af5550fb92913d5cf6165e58fa796 . "./code.cg2js/cg-yes-no-string.fasl")
(#x1d69f0be1f681a2ac440f7e08313f0cb . "./code.idejs/ide-acache.fasl")
(#x78c4a37f4e363ac06c3ab7331a0e860e . "./code.idejs/ide-apropos.fasl")
(#x3037b3660c23e1ba89ad3f783e206fe7 . "./code.idejs/ide-base.fasl")
(#x7348d8efe4c8c1c509d6d486bf28e9ce . "./code.idejs/ide-class-browser.fasl")
(#x221747e0989675c1570435c24fa83fa7 . "./code.idejs/ide-class-grapher.fasl")
(#xe4e717c135a0edcbb05589965ef92830 . "./code.idejs/ide-clipboard.fasl")
(#x41c06c06e7dec5e872080d99d79307c5 . "./code.idejs/ide-dev.fasl")
(#xe7b9bb6b635384a653aa30207f654df0 . "./code.idejs/ide-editor.fasl")
(#x2ee8864016d0128036fd256f9dca5341 . "./code.idejs/ide-find-definitions.fasl")
(#x4debe7164b7e196e47b9658e8ad7cf8f . "./code.idejs/ide-find-in-files.fasl")
(#xd52c8d481eac62307eb92add9fc35524 . "./code.idejs/ide-form.fasl")
(#x804b66c96bc727b527da34cb3488b6bb . "./code.idejs/ide-grapher.fasl")
(#x3c03845c43fe92b1b527dc9e7b12eb9f . "./code.idejs/ide-inspector.fasl")
(#x2f3ca7becf6dc2d85f2b5fce348ca350 . "./code.idejs/ide-intro.fasl")
(#x0e8f827a5deceb8fb7e3d882b0dc24ae . "./code.idejs/ide-keyshort.fasl")
(#x8eaee72366c8ec05b3103b52f44e7ebc . "./code.idejs/ide-navigator.fasl")
(#x8fa3769af5e230b73c66d13b3c3a218a . "./code.idejs/ide-package-list.fasl")
(#x077d57d9f438bbb166e151d93fd14ace . "./code.idejs/ide-patch-dialog.fasl")
(#x3ab7f2d42c4d81d73d9a59c1451482d0 . "./code.idejs/ide-process-browser.fasl")
(#x16b9e1301a8c9831d7792f958d34895c . "./code.idejs/ide-project.fasl")
(#x6bb959512c83fed65da8a7c0325ea733 . "./code.idejs/ide-trace.fasl")
(#xa1da12a082f5cfb15c428b16e35cd98b . "./code.idejs/ide-window-list.fasl")
(#x98f0eb24778f800ea043d65cf39e104d . "./code.idejs/ide.fasl")
(#x68149b79128815fb04933c4813dbe32f . "./cgjs.html")
(#x55fea08d92e113f5a8381c271febbc9e . "./ssl-not-found.html")
(#x4e1b21622d7d9cc4e6fc09c7875f8430 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js" "code.idejs"))
    (format s "
(let ((path (make-pathname
             :host \"sys\"
             :directory '(:relative \"~a\")
	     :type \"fasl\"
	     )))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
